@@ -3,6 +3,8 @@ import sys
 import importlib
 DOCKER_IMAGE_NAME = "styczynski/eniam:0.1.1"
 
+from .eniam_syntax import SUPPORTED_VALUES
+
 from base64 import b64encode
 import time
 import sys
@@ -350,7 +352,11 @@ class Eniam():
 
         lexicon_custom = []
         for key in lexicon:
-            if key == "__root__":
+            if "__pos__" in key:
+                for pos in SUPPORTED_VALUES:
+                    key_str = ",".join([key.replace("__pos__", ""), f"pos={pos}"])
+                    lexicon_custom.append(f"{key_str}: {lexicon[key]};")
+            elif key == "__root__":
                 lexicon_custom.append(f"lemma=</sentence>,pos=interp:     BRACKET {lexicon[key]};")
             else:
                 lexicon_custom.append(f"{key}: {lexicon[key]};")
