@@ -17,7 +17,7 @@ SUPPORTED_VALUES = {
         "bedzie", "praet", "winien", "impt", "imps",
         "pred", "aglt", "inf", "pcon", "pant", "qub",
         "comp", "conj", "interj", "sinterj", "burk", "interp",
-        "unk"
+        "unk", "apron"
     ],
     "number": [ "sg", "pl" ],
     "case": [
@@ -84,4 +84,4 @@ def rule(
             val = locals()[key]
             if val is not None:
                 output.append(f"{key}={val}")
-    return ",".join(output)
\ No newline at end of file
+    return ",".join(output)
